@@ -258,9 +258,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import Duration as _Duration_070aa057
 from ..aws_apigatewayv2 import (
     HttpRouteAuthorizerBindOptions as _HttpRouteAuthorizerBindOptions_290d6475,
@@ -321,7 +323,7 @@ class HttpIamAuthorizer(
         self,
         *,
         route: _IHttpRoute_bfbdc841,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> _HttpRouteAuthorizerConfig_cd6b9e02:
         '''(experimental) Bind this authorizer to a specified Http route.
 
@@ -384,6 +386,10 @@ class HttpJwtAuthorizer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__81352bc6fb807f777316023d81156cab5c4f5855a592bd59cf575feb27426443)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument jwt_issuer", value=jwt_issuer, expected_type=type_hints["jwt_issuer"])
         props = HttpJwtAuthorizerProps(
             jwt_audience=jwt_audience,
             authorizer_name=authorizer_name,
@@ -397,7 +403,7 @@ class HttpJwtAuthorizer(
         self,
         *,
         route: _IHttpRoute_bfbdc841,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> _HttpRouteAuthorizerConfig_cd6b9e02:
         '''(experimental) Bind this authorizer to a specified Http route.
 
@@ -456,7 +462,12 @@ class HttpJwtAuthorizerProps:
                 authorizer=authorizer
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__923292d1ab985742e739bc08f0466dfb8bbe142f7b0d2a38cc0d4e11a3ad3ee1)
+            check_type(argname="argument jwt_audience", value=jwt_audience, expected_type=type_hints["jwt_audience"])
+            check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
+            check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "jwt_audience": jwt_audience,
         }
         if authorizer_name is not None:
@@ -563,6 +574,10 @@ class HttpLambdaAuthorizer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__2e81f250bfd3600b0c133aacea7e7847a163747ec802264deff883fa66dc5362)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
         props = HttpLambdaAuthorizerProps(
             authorizer_name=authorizer_name,
             identity_source=identity_source,
@@ -577,7 +592,7 @@ class HttpLambdaAuthorizer(
         self,
         *,
         route: _IHttpRoute_bfbdc841,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> _HttpRouteAuthorizerConfig_cd6b9e02:
         '''(experimental) Bind this authorizer to a specified Http route.
 
@@ -641,7 +656,13 @@ class HttpLambdaAuthorizerProps:
                 authorizer=authorizer
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__38866fb7591e0a2792251b29e176310d74fba0ba02ad33bd59e7bd72919d0c0f)
+            check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
+            check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
+            check_type(argname="argument response_types", value=response_types, expected_type=type_hints["response_types"])
+            check_type(argname="argument results_cache_ttl", value=results_cache_ttl, expected_type=type_hints["results_cache_ttl"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if authorizer_name is not None:
             self._values["authorizer_name"] = authorizer_name
         if identity_source is not None:
@@ -784,6 +805,10 @@ class HttpUserPoolAuthorizer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__d22a41e027da40b3c4136be8781dfcc3b42050cc6c9bfc6511ca0e8ac42530d0)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument pool", value=pool, expected_type=type_hints["pool"])
         props = HttpUserPoolAuthorizerProps(
             authorizer_name=authorizer_name,
             identity_source=identity_source,
@@ -798,7 +823,7 @@ class HttpUserPoolAuthorizer(
         self,
         *,
         route: _IHttpRoute_bfbdc841,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> _HttpRouteAuthorizerConfig_cd6b9e02:
         '''(experimental) Bind this authorizer to a specified Http route.
 
@@ -857,7 +882,13 @@ class HttpUserPoolAuthorizerProps:
                 user_pool_region="userPoolRegion"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__9477169a7b315b927c801b25d172d8ac42e63632a0337b4115009e7f64a37bf6)
+            check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
+            check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
+            check_type(argname="argument user_pool_clients", value=user_pool_clients, expected_type=type_hints["user_pool_clients"])
+            check_type(argname="argument user_pool_region", value=user_pool_region, expected_type=type_hints["user_pool_region"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if authorizer_name is not None:
             self._values["authorizer_name"] = authorizer_name
         if identity_source is not None:
@@ -975,6 +1006,10 @@ class WebSocketLambdaAuthorizer(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__cf96e78d478aeecf99c20b875c60c1bfbfdcbd6f4bff1b74ee1032d6533cfb65)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
         props = WebSocketLambdaAuthorizerProps(
             authorizer_name=authorizer_name, identity_source=identity_source
         )
@@ -986,7 +1021,7 @@ class WebSocketLambdaAuthorizer(
         self,
         *,
         route: _IWebSocketRoute_bcd0851a,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> _WebSocketRouteAuthorizerConfig_d5e8509a:
         '''(experimental) Bind this authorizer to a specified WebSocket route.
 
@@ -1036,7 +1071,11 @@ class WebSocketLambdaAuthorizerProps:
                 identity_source=["identitySource"]
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__07f78510189474e333e6affdbdfe83c07457be44c80c0531a1b0f806f3e7b61e)
+            check_type(argname="argument authorizer_name", value=authorizer_name, expected_type=type_hints["authorizer_name"])
+            check_type(argname="argument identity_source", value=identity_source, expected_type=type_hints["identity_source"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if authorizer_name is not None:
             self._values["authorizer_name"] = authorizer_name
         if identity_source is not None:
@@ -1094,3 +1133,85 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__81352bc6fb807f777316023d81156cab5c4f5855a592bd59cf575feb27426443(
+    id: builtins.str,
+    jwt_issuer: builtins.str,
+    *,
+    jwt_audience: typing.Sequence[builtins.str],
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__923292d1ab985742e739bc08f0466dfb8bbe142f7b0d2a38cc0d4e11a3ad3ee1(
+    *,
+    jwt_audience: typing.Sequence[builtins.str],
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2e81f250bfd3600b0c133aacea7e7847a163747ec802264deff883fa66dc5362(
+    id: builtins.str,
+    handler: _IFunction_6e14f09e,
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+    response_types: typing.Optional[typing.Sequence[HttpLambdaResponseType]] = None,
+    results_cache_ttl: typing.Optional[_Duration_070aa057] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__38866fb7591e0a2792251b29e176310d74fba0ba02ad33bd59e7bd72919d0c0f(
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+    response_types: typing.Optional[typing.Sequence[HttpLambdaResponseType]] = None,
+    results_cache_ttl: typing.Optional[_Duration_070aa057] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d22a41e027da40b3c4136be8781dfcc3b42050cc6c9bfc6511ca0e8ac42530d0(
+    id: builtins.str,
+    pool: _IUserPool_5e500460,
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+    user_pool_clients: typing.Optional[typing.Sequence[_IUserPoolClient_4cdf19bd]] = None,
+    user_pool_region: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9477169a7b315b927c801b25d172d8ac42e63632a0337b4115009e7f64a37bf6(
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+    user_pool_clients: typing.Optional[typing.Sequence[_IUserPoolClient_4cdf19bd]] = None,
+    user_pool_region: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cf96e78d478aeecf99c20b875c60c1bfbfdcbd6f4bff1b74ee1032d6533cfb65(
+    id: builtins.str,
+    handler: _IFunction_6e14f09e,
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__07f78510189474e333e6affdbdfe83c07457be44c80c0531a1b0f806f3e7b61e(
+    *,
+    authorizer_name: typing.Optional[builtins.str] = None,
+    identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
