@@ -33,7 +33,7 @@ cloud9.Ec2Environment(self, "Cloud9Env2",
 c9env = cloud9.Ec2Environment(self, "Cloud9Env3",
     vpc=vpc,
     subnet_selection=cloud9.aws_ec2.SubnetSelection(
-        subnet_type=ec2.SubnetType.PRIVATE
+        subnet_type=ec2.SubnetType.PRIVATE_WITH_NAT
     )
 )
 
@@ -78,9 +78,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     CfnResource as _CfnResource_e0a482dc,
     CfnTag as _CfnTag_95fbdc29,
@@ -154,9 +156,9 @@ class CfnEnvironmentEC2(
         image_id: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
         owner_arn: typing.Optional[builtins.str] = None,
-        repositories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _IResolvable_a771d0ef]]]] = None,
+        repositories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnEnvironmentEC2.RepositoryProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
         subnet_id: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[_CfnTag_95fbdc29]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Create a new ``AWS::Cloud9::EnvironmentEC2``.
 
@@ -173,6 +175,10 @@ class CfnEnvironmentEC2(
         :param subnet_id: The ID of the subnet in Amazon Virtual Private Cloud (Amazon VPC) that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
         :param tags: An array of key-value pairs that will be associated with the new AWS Cloud9 development environment.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__d356b65331f1459268f6a47818602255425f9c12a4974b287fdead28b7174f17)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnEnvironmentEC2Props(
             instance_type=instance_type,
             automatic_stop_time_minutes=automatic_stop_time_minutes,
@@ -194,6 +200,9 @@ class CfnEnvironmentEC2(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8ac0ad1bc1a8921349319ef6a5586230bb868743274440976e6f870d483abecb)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -204,15 +213,18 @@ class CfnEnvironmentEC2(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__dd211bc666c293dadc050060ca9d88fd7eff588f5017fa04538993d4ed19a44f)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         '''The Amazon Resource Name (ARN) of the development environment, such as ``arn:aws:cloud9:us-east-2:123456789012:environment:2bc3642873c342e485f7e0c561234567`` .
@@ -221,7 +233,7 @@ class CfnEnvironmentEC2(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrName")
     def attr_name(self) -> builtins.str:
         '''The name of the environment.
@@ -230,12 +242,12 @@ class CfnEnvironmentEC2(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_0b7ab120:
         '''An array of key-value pairs that will be associated with the new AWS Cloud9 development environment.
@@ -244,7 +256,7 @@ class CfnEnvironmentEC2(
         '''
         return typing.cast(_TagManager_0b7ab120, jsii.get(self, "tags"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="instanceType")
     def instance_type(self) -> builtins.str:
         '''The type of instance to connect to the environment (for example, ``t2.micro`` ).
@@ -255,9 +267,12 @@ class CfnEnvironmentEC2(
 
     @instance_type.setter
     def instance_type(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__c521c1bd02276042ae84f2a22ff101e7747eba53a09005d3d1a7576146d8710e)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceType", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="automaticStopTimeMinutes")
     def automatic_stop_time_minutes(self) -> typing.Optional[jsii.Number]:
         '''The number of minutes until the running instance is shut down after the environment was last used.
@@ -268,9 +283,12 @@ class CfnEnvironmentEC2(
 
     @automatic_stop_time_minutes.setter
     def automatic_stop_time_minutes(self, value: typing.Optional[jsii.Number]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__055c588a4df79ba5696606cb5abe59dc7720b88577f7520661f1d7c231e68938)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "automaticStopTimeMinutes", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="connectionType")
     def connection_type(self) -> typing.Optional[builtins.str]:
         '''The connection type used for connecting to an Amazon EC2 environment.
@@ -283,9 +301,12 @@ class CfnEnvironmentEC2(
 
     @connection_type.setter
     def connection_type(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__706417cdf57271eff685ef712b2467ec160f2f570256cd90fa65fb989e409f8c)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "connectionType", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="description")
     def description(self) -> typing.Optional[builtins.str]:
         '''The description of the environment to create.
@@ -296,9 +317,12 @@ class CfnEnvironmentEC2(
 
     @description.setter
     def description(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__06fbea5c29145e4f30761f13cd1693c5d9e624d9d9b2f6ed467563f132ef03f3)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="imageId")
     def image_id(self) -> typing.Optional[builtins.str]:
         '''The identifier for the Amazon Machine Image (AMI) that's used to create the EC2 instance.
@@ -325,9 +349,12 @@ class CfnEnvironmentEC2(
 
     @image_id.setter
     def image_id(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__04f4f92e5d9ca1f9c529fac449880dea1dac761ac27c7ac40d8803d8ae4dbb9c)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "imageId", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> typing.Optional[builtins.str]:
         '''The name of the environment.
@@ -338,9 +365,12 @@ class CfnEnvironmentEC2(
 
     @name.setter
     def name(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__3af99bf17275529641cfc8952b91e3e0e50d9d3733d33d1af57e8652095e6364)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ownerArn")
     def owner_arn(self) -> typing.Optional[builtins.str]:
         '''The Amazon Resource Name (ARN) of the environment owner.
@@ -353,9 +383,12 @@ class CfnEnvironmentEC2(
 
     @owner_arn.setter
     def owner_arn(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__33affd85d91fc0831d85ff239738fdd2bac27058c94708a16efad979a2026a84)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ownerArn", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositories")
     def repositories(
         self,
@@ -371,9 +404,12 @@ class CfnEnvironmentEC2(
         self,
         value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", _IResolvable_a771d0ef]]]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__748b851567c2f5593529f851d505958a7baaad66af5c7f6fa3596fa03a189fac)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositories", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="subnetId")
     def subnet_id(self) -> typing.Optional[builtins.str]:
         '''The ID of the subnet in Amazon Virtual Private Cloud (Amazon VPC) that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
@@ -384,6 +420,9 @@ class CfnEnvironmentEC2(
 
     @subnet_id.setter
     def subnet_id(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__80c30419ac252872b9e54d6cf0c24b92b1b985d94a2aa910dbc24f117808e22d)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "subnetId", value)
 
     @jsii.data_type(
@@ -420,7 +459,11 @@ class CfnEnvironmentEC2(
                     repository_url="repositoryUrl"
                 )
             '''
-            self._values: typing.Dict[str, typing.Any] = {
+            if __debug__:
+                type_hints = typing.get_type_hints(_typecheckingstub__32e0b1891fce4f17c47054a9bdaed22cb2aad87e47e1156a6f1a0eb98a222120)
+                check_type(argname="argument path_component", value=path_component, expected_type=type_hints["path_component"])
+                check_type(argname="argument repository_url", value=repository_url, expected_type=type_hints["repository_url"])
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "path_component": path_component,
                 "repository_url": repository_url,
             }
@@ -488,9 +531,9 @@ class CfnEnvironmentEC2Props:
         image_id: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
         owner_arn: typing.Optional[builtins.str] = None,
-        repositories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[CfnEnvironmentEC2.RepositoryProperty, _IResolvable_a771d0ef]]]] = None,
+        repositories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
         subnet_id: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[_CfnTag_95fbdc29]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''Properties for defining a ``CfnEnvironmentEC2``.
 
@@ -535,7 +578,19 @@ class CfnEnvironmentEC2Props:
                 )]
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__3ef12054c241242ffbb8227d2ee807fb357b00abcc9bb43dd25444f754c43082)
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument automatic_stop_time_minutes", value=automatic_stop_time_minutes, expected_type=type_hints["automatic_stop_time_minutes"])
+            check_type(argname="argument connection_type", value=connection_type, expected_type=type_hints["connection_type"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument image_id", value=image_id, expected_type=type_hints["image_id"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument owner_arn", value=owner_arn, expected_type=type_hints["owner_arn"])
+            check_type(argname="argument repositories", value=repositories, expected_type=type_hints["repositories"])
+            check_type(argname="argument subnet_id", value=subnet_id, expected_type=type_hints["subnet_id"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "instance_type": instance_type,
         }
         if automatic_stop_time_minutes is not None:
@@ -715,7 +770,7 @@ class CloneRepository(
         )
     '''
 
-    @jsii.member(jsii_name="fromCodeCommit") # type: ignore[misc]
+    @jsii.member(jsii_name="fromCodeCommit")
     @builtins.classmethod
     def from_code_commit(
         cls,
@@ -729,9 +784,13 @@ class CloneRepository(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8e5218ebacf45e1f5aedf54766c1a9536ebe089ba4488e7fdddae153994469ec)
+            check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         return typing.cast("CloneRepository", jsii.sinvoke(cls, "fromCodeCommit", [repository, path]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="pathComponent")
     def path_component(self) -> builtins.str:
         '''
@@ -739,7 +798,7 @@ class CloneRepository(
         '''
         return typing.cast(builtins.str, jsii.get(self, "pathComponent"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositoryUrl")
     def repository_url(self) -> builtins.str:
         '''
@@ -748,12 +807,32 @@ class CloneRepository(
         return typing.cast(builtins.str, jsii.get(self, "repositoryUrl"))
 
 
+@jsii.enum(jsii_type="monocdk.aws_cloud9.ConnectionType")
+class ConnectionType(enum.Enum):
+    '''(experimental) The connection type used for connecting to an Amazon EC2 environment.
+
+    :stability: experimental
+    '''
+
+    CONNECT_SSH = "CONNECT_SSH"
+    '''(experimental) Conect through SSH.
+
+    :stability: experimental
+    '''
+    CONNECT_SSM = "CONNECT_SSM"
+    '''(experimental) Connect through AWS Systems Manager.
+
+    :stability: experimental
+    '''
+
+
 @jsii.data_type(
     jsii_type="monocdk.aws_cloud9.Ec2EnvironmentProps",
     jsii_struct_bases=[],
     name_mapping={
         "vpc": "vpc",
         "cloned_repositories": "clonedRepositories",
+        "connection_type": "connectionType",
         "description": "description",
         "ec2_environment_name": "ec2EnvironmentName",
         "instance_type": "instanceType",
@@ -766,15 +845,17 @@ class Ec2EnvironmentProps:
         *,
         vpc: _IVpc_6d1f76c4,
         cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
+        connection_type: typing.Optional[ConnectionType] = None,
         description: typing.Optional[builtins.str] = None,
         ec2_environment_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[_InstanceType_072ad323] = None,
-        subnet_selection: typing.Optional[_SubnetSelection_1284e62c] = None,
+        subnet_selection: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) Properties for Ec2Environment.
 
         :param vpc: (experimental) The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
         :param cloned_repositories: (experimental) The AWS CodeCommit repository to be cloned. Default: - do not clone any repository
+        :param connection_type: (experimental) The connection type used for connecting to an Amazon EC2 environment. Valid values are: CONNECT_SSH (default) and CONNECT_SSM (connected through AWS Systems Manager) Default: - CONNECT_SSH
         :param description: (experimental) Description of the environment. Default: - no description
         :param ec2_environment_name: (experimental) Name of the environment. Default: - automatically generated name
         :param instance_type: (experimental) The type of instance to connect to the environment. Default: - t2.micro
@@ -800,7 +881,7 @@ class Ec2EnvironmentProps:
             c9env = cloud9.Ec2Environment(self, "Cloud9Env3",
                 vpc=vpc,
                 subnet_selection=cloud9.aws_ec2.SubnetSelection(
-                    subnet_type=ec2.SubnetType.PRIVATE
+                    subnet_type=ec2.SubnetType.PRIVATE_WITH_NAT
                 )
             )
             
@@ -809,11 +890,22 @@ class Ec2EnvironmentProps:
         '''
         if isinstance(subnet_selection, dict):
             subnet_selection = _SubnetSelection_1284e62c(**subnet_selection)
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__72417e6000af6f0e30b13e2b1e5236060852b74a8f4c744c3b54a53fae2f1be7)
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument cloned_repositories", value=cloned_repositories, expected_type=type_hints["cloned_repositories"])
+            check_type(argname="argument connection_type", value=connection_type, expected_type=type_hints["connection_type"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument ec2_environment_name", value=ec2_environment_name, expected_type=type_hints["ec2_environment_name"])
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument subnet_selection", value=subnet_selection, expected_type=type_hints["subnet_selection"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "vpc": vpc,
         }
         if cloned_repositories is not None:
             self._values["cloned_repositories"] = cloned_repositories
+        if connection_type is not None:
+            self._values["connection_type"] = connection_type
         if description is not None:
             self._values["description"] = description
         if ec2_environment_name is not None:
@@ -844,6 +936,19 @@ class Ec2EnvironmentProps:
         result = self._values.get("cloned_repositories")
         return typing.cast(typing.Optional[typing.List[CloneRepository]], result)
 
+    @builtins.property
+    def connection_type(self) -> typing.Optional[ConnectionType]:
+        '''(experimental) The connection type used for connecting to an Amazon EC2 environment.
+
+        Valid values are: CONNECT_SSH (default) and CONNECT_SSM (connected through AWS Systems Manager)
+
+        :default: - CONNECT_SSH
+
+        :stability: experimental
+        '''
+        result = self._values.get("connection_type")
+        return typing.cast(typing.Optional[ConnectionType], result)
+
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
         '''(experimental) Description of the environment.
@@ -907,7 +1012,7 @@ class IEc2Environment(_IResource_8c1dbbbd, typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentArn")
     def ec2_environment_arn(self) -> builtins.str:
         '''(experimental) The arn of the EnvironmentEc2.
@@ -917,7 +1022,7 @@ class IEc2Environment(_IResource_8c1dbbbd, typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentName")
     def ec2_environment_name(self) -> builtins.str:
         '''(experimental) The name of the EnvironmentEc2.
@@ -929,7 +1034,7 @@ class IEc2Environment(_IResource_8c1dbbbd, typing_extensions.Protocol):
 
 
 class _IEc2EnvironmentProxy(
-    jsii.proxy_for(_IResource_8c1dbbbd) # type: ignore[misc]
+    jsii.proxy_for(_IResource_8c1dbbbd), # type: ignore[misc]
 ):
     '''(experimental) A Cloud9 Environment.
 
@@ -938,7 +1043,7 @@ class _IEc2EnvironmentProxy(
 
     __jsii_type__: typing.ClassVar[str] = "monocdk.aws_cloud9.IEc2Environment"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentArn")
     def ec2_environment_arn(self) -> builtins.str:
         '''(experimental) The arn of the EnvironmentEc2.
@@ -948,7 +1053,7 @@ class _IEc2EnvironmentProxy(
         '''
         return typing.cast(builtins.str, jsii.get(self, "ec2EnvironmentArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentName")
     def ec2_environment_name(self) -> builtins.str:
         '''(experimental) The name of the EnvironmentEc2.
@@ -971,8 +1076,8 @@ class Ec2Environment(
     '''(experimental) A Cloud9 Environment with Amazon EC2.
 
     :stability: experimental
-    :exampleMetadata: infused
     :resource: AWS::Cloud9::EnvironmentEC2
+    :exampleMetadata: infused
 
     Example::
 
@@ -991,7 +1096,7 @@ class Ec2Environment(
         c9env = cloud9.Ec2Environment(self, "Cloud9Env3",
             vpc=vpc,
             subnet_selection=cloud9.aws_ec2.SubnetSelection(
-                subnet_type=ec2.SubnetType.PRIVATE
+                subnet_type=ec2.SubnetType.PRIVATE_WITH_NAT
             )
         )
         
@@ -1001,21 +1106,23 @@ class Ec2Environment(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         vpc: _IVpc_6d1f76c4,
         cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
+        connection_type: typing.Optional[ConnectionType] = None,
         description: typing.Optional[builtins.str] = None,
         ec2_environment_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[_InstanceType_072ad323] = None,
-        subnet_selection: typing.Optional[_SubnetSelection_1284e62c] = None,
+        subnet_selection: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
         :param vpc: (experimental) The VPC that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
         :param cloned_repositories: (experimental) The AWS CodeCommit repository to be cloned. Default: - do not clone any repository
+        :param connection_type: (experimental) The connection type used for connecting to an Amazon EC2 environment. Valid values are: CONNECT_SSH (default) and CONNECT_SSM (connected through AWS Systems Manager) Default: - CONNECT_SSH
         :param description: (experimental) Description of the environment. Default: - no description
         :param ec2_environment_name: (experimental) Name of the environment. Default: - automatically generated name
         :param instance_type: (experimental) The type of instance to connect to the environment. Default: - t2.micro
@@ -1023,9 +1130,14 @@ class Ec2Environment(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__2ccd9265138381bb8cb164ceac67896c34661ba6f34649b836c1c7c3c967f031)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = Ec2EnvironmentProps(
             vpc=vpc,
             cloned_repositories=cloned_repositories,
+            connection_type=connection_type,
             description=description,
             ec2_environment_name=ec2_environment_name,
             instance_type=instance_type,
@@ -1034,11 +1146,11 @@ class Ec2Environment(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromEc2EnvironmentName") # type: ignore[misc]
+    @jsii.member(jsii_name="fromEc2EnvironmentName")
     @builtins.classmethod
     def from_ec2_environment_name(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         ec2_environment_name: builtins.str,
     ) -> IEc2Environment:
@@ -1050,9 +1162,14 @@ class Ec2Environment(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__93a54c59d50f033812f8c790f3e01ffdffe2133412b4f6f186293c32504709c3)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument ec2_environment_name", value=ec2_environment_name, expected_type=type_hints["ec2_environment_name"])
         return typing.cast(IEc2Environment, jsii.sinvoke(cls, "fromEc2EnvironmentName", [scope, id, ec2_environment_name]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentArn")
     def ec2_environment_arn(self) -> builtins.str:
         '''(experimental) The environment ARN of this Cloud9 environment.
@@ -1062,7 +1179,7 @@ class Ec2Environment(
         '''
         return typing.cast(builtins.str, jsii.get(self, "ec2EnvironmentArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ec2EnvironmentName")
     def ec2_environment_name(self) -> builtins.str:
         '''(experimental) The environment name of this Cloud9 environment.
@@ -1072,7 +1189,7 @@ class Ec2Environment(
         '''
         return typing.cast(builtins.str, jsii.get(self, "ec2EnvironmentName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="environmentId")
     def environment_id(self) -> builtins.str:
         '''(experimental) The environment ID of this Cloud9 environment.
@@ -1081,7 +1198,7 @@ class Ec2Environment(
         '''
         return typing.cast(builtins.str, jsii.get(self, "environmentId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ideUrl")
     def ide_url(self) -> builtins.str:
         '''(experimental) The complete IDE URL of this Cloud9 environment.
@@ -1090,7 +1207,7 @@ class Ec2Environment(
         '''
         return typing.cast(builtins.str, jsii.get(self, "ideUrl"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> _IVpc_6d1f76c4:
         '''(experimental) VPC ID.
@@ -1104,9 +1221,161 @@ __all__ = [
     "CfnEnvironmentEC2",
     "CfnEnvironmentEC2Props",
     "CloneRepository",
+    "ConnectionType",
     "Ec2Environment",
     "Ec2EnvironmentProps",
     "IEc2Environment",
 ]
 
 publication.publish()
+
+def _typecheckingstub__d356b65331f1459268f6a47818602255425f9c12a4974b287fdead28b7174f17(
+    scope: _Construct_e78e779f,
+    id: builtins.str,
+    *,
+    instance_type: builtins.str,
+    automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
+    connection_type: typing.Optional[builtins.str] = None,
+    description: typing.Optional[builtins.str] = None,
+    image_id: typing.Optional[builtins.str] = None,
+    name: typing.Optional[builtins.str] = None,
+    owner_arn: typing.Optional[builtins.str] = None,
+    repositories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
+    subnet_id: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8ac0ad1bc1a8921349319ef6a5586230bb868743274440976e6f870d483abecb(
+    inspector: _TreeInspector_1cd1894e,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dd211bc666c293dadc050060ca9d88fd7eff588f5017fa04538993d4ed19a44f(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c521c1bd02276042ae84f2a22ff101e7747eba53a09005d3d1a7576146d8710e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__055c588a4df79ba5696606cb5abe59dc7720b88577f7520661f1d7c231e68938(
+    value: typing.Optional[jsii.Number],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__706417cdf57271eff685ef712b2467ec160f2f570256cd90fa65fb989e409f8c(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__06fbea5c29145e4f30761f13cd1693c5d9e624d9d9b2f6ed467563f132ef03f3(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__04f4f92e5d9ca1f9c529fac449880dea1dac761ac27c7ac40d8803d8ae4dbb9c(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3af99bf17275529641cfc8952b91e3e0e50d9d3733d33d1af57e8652095e6364(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__33affd85d91fc0831d85ff239738fdd2bac27058c94708a16efad979a2026a84(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__748b851567c2f5593529f851d505958a7baaad66af5c7f6fa3596fa03a189fac(
+    value: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnEnvironmentEC2.RepositoryProperty, _IResolvable_a771d0ef]]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__80c30419ac252872b9e54d6cf0c24b92b1b985d94a2aa910dbc24f117808e22d(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__32e0b1891fce4f17c47054a9bdaed22cb2aad87e47e1156a6f1a0eb98a222120(
+    *,
+    path_component: builtins.str,
+    repository_url: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3ef12054c241242ffbb8227d2ee807fb357b00abcc9bb43dd25444f754c43082(
+    *,
+    instance_type: builtins.str,
+    automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
+    connection_type: typing.Optional[builtins.str] = None,
+    description: typing.Optional[builtins.str] = None,
+    image_id: typing.Optional[builtins.str] = None,
+    name: typing.Optional[builtins.str] = None,
+    owner_arn: typing.Optional[builtins.str] = None,
+    repositories: typing.Optional[typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]]] = None,
+    subnet_id: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Sequence[typing.Union[_CfnTag_95fbdc29, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8e5218ebacf45e1f5aedf54766c1a9536ebe089ba4488e7fdddae153994469ec(
+    repository: _IRepository_cdb2a3c0,
+    path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__72417e6000af6f0e30b13e2b1e5236060852b74a8f4c744c3b54a53fae2f1be7(
+    *,
+    vpc: _IVpc_6d1f76c4,
+    cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
+    connection_type: typing.Optional[ConnectionType] = None,
+    description: typing.Optional[builtins.str] = None,
+    ec2_environment_name: typing.Optional[builtins.str] = None,
+    instance_type: typing.Optional[_InstanceType_072ad323] = None,
+    subnet_selection: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2ccd9265138381bb8cb164ceac67896c34661ba6f34649b836c1c7c3c967f031(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    vpc: _IVpc_6d1f76c4,
+    cloned_repositories: typing.Optional[typing.Sequence[CloneRepository]] = None,
+    connection_type: typing.Optional[ConnectionType] = None,
+    description: typing.Optional[builtins.str] = None,
+    ec2_environment_name: typing.Optional[builtins.str] = None,
+    instance_type: typing.Optional[_InstanceType_072ad323] = None,
+    subnet_selection: typing.Optional[typing.Union[_SubnetSelection_1284e62c, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__93a54c59d50f033812f8c790f3e01ffdffe2133412b4f6f186293c32504709c3(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    ec2_environment_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
