@@ -35,9 +35,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     CfnResource as _CfnResource_e0a482dc,
     Construct as _Construct_e78e779f,
@@ -100,7 +102,7 @@ class CfnGitHubRepository(
         *,
         repository_name: builtins.str,
         repository_owner: builtins.str,
-        code: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_a771d0ef]] = None,
+        code: typing.Optional[typing.Union[typing.Union["CfnGitHubRepository.CodeProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
         connection_arn: typing.Optional[builtins.str] = None,
         enable_issues: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
         is_private: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
@@ -120,6 +122,10 @@ class CfnGitHubRepository(
         :param repository_access_token: The GitHub user's personal access token for the GitHub repository.
         :param repository_description: A comment or description about the new repository. This description is displayed in GitHub after the repository is created.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8e6417a8cd803b26540e4b0aeb36c45a341ff26da7e791df675df50fb97584c4)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnGitHubRepositoryProps(
             repository_name=repository_name,
             repository_owner=repository_owner,
@@ -139,6 +145,9 @@ class CfnGitHubRepository(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__e316e6706e3d8c947158e9450f45c1c0ce5b1b7d89bbac929d3e37a79a874fc3)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -149,20 +158,23 @@ class CfnGitHubRepository(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__cd458298fc1e20ba4a7ff1d912df53387d79a747e37d7a388fc8e490b1f7a8d0)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositoryName")
     def repository_name(self) -> builtins.str:
         '''The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
@@ -173,9 +185,12 @@ class CfnGitHubRepository(
 
     @repository_name.setter
     def repository_name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__78ad89e3d016b25b56cffa283f881b0d0f6a6ac7e932d07e77309aa8bfab79ad)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryName", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositoryOwner")
     def repository_owner(self) -> builtins.str:
         '''The GitHub user name for the owner of the GitHub repository to be created.
@@ -188,9 +203,12 @@ class CfnGitHubRepository(
 
     @repository_owner.setter
     def repository_owner(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__e100b8474946ec04f4b7eee7ef43bf55a420a9bef06925b5b6caf56a5e3ff1d0)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryOwner", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="code")
     def code(
         self,
@@ -206,9 +224,12 @@ class CfnGitHubRepository(
         self,
         value: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", _IResolvable_a771d0ef]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__06fdac87038483579345a9d6e16a8575f32eb023fd4accf654d2d02f77114e71)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "code", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="connectionArn")
     def connection_arn(self) -> typing.Optional[builtins.str]:
         '''``AWS::CodeStar::GitHubRepository.ConnectionArn``.
@@ -219,9 +240,12 @@ class CfnGitHubRepository(
 
     @connection_arn.setter
     def connection_arn(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__c0ba8394d7ea0b0c6071ce2aafef37306e47a68e53ea2cef4deeba55a7342f99)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "connectionArn", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableIssues")
     def enable_issues(
         self,
@@ -239,9 +263,12 @@ class CfnGitHubRepository(
         self,
         value: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__5402b5c800b0a50cb0141a0d17dd4219f94ff7e43b6c26a07a63b3c2e88bcdb7)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableIssues", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="isPrivate")
     def is_private(
         self,
@@ -259,9 +286,12 @@ class CfnGitHubRepository(
         self,
         value: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__bfd7dbdce873af1a204d661071d9d24c0d4bf72acfbe3dba81f1c9736ad4016c)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "isPrivate", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositoryAccessToken")
     def repository_access_token(self) -> typing.Optional[builtins.str]:
         '''The GitHub user's personal access token for the GitHub repository.
@@ -272,9 +302,12 @@ class CfnGitHubRepository(
 
     @repository_access_token.setter
     def repository_access_token(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__01d8678cd01273d281a5e55ee2af6acc9e50cc0f76c18cd129b895b27b681911)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryAccessToken", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repositoryDescription")
     def repository_description(self) -> typing.Optional[builtins.str]:
         '''A comment or description about the new repository.
@@ -287,6 +320,9 @@ class CfnGitHubRepository(
 
     @repository_description.setter
     def repository_description(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__2f2170856c0701f4ac4b7480e4d4e6c71d349c174fbbd977f616360503a7e403)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryDescription", value)
 
     @jsii.data_type(
@@ -298,7 +334,7 @@ class CfnGitHubRepository(
         def __init__(
             self,
             *,
-            s3: typing.Union["CfnGitHubRepository.S3Property", _IResolvable_a771d0ef],
+            s3: typing.Union[typing.Union["CfnGitHubRepository.S3Property", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
         ) -> None:
             '''The ``Code`` property type specifies information about code to be committed.
 
@@ -325,7 +361,10 @@ class CfnGitHubRepository(
                     )
                 )
             '''
-            self._values: typing.Dict[str, typing.Any] = {
+            if __debug__:
+                type_hints = typing.get_type_hints(_typecheckingstub__151b349c77f1a4f8ded96e7a22c46e35ac66f8e14e1da6dedbbed79e929b9805)
+                check_type(argname="argument s3", value=s3, expected_type=type_hints["s3"])
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "s3": s3,
             }
 
@@ -394,7 +433,12 @@ class CfnGitHubRepository(
                     object_version="objectVersion"
                 )
             '''
-            self._values: typing.Dict[str, typing.Any] = {
+            if __debug__:
+                type_hints = typing.get_type_hints(_typecheckingstub__51e1fbe1a2a485214d39aeb1220ee489138a0d32cffa831dc40b075b935090d9)
+                check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+                check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+                check_type(argname="argument object_version", value=object_version, expected_type=type_hints["object_version"])
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "bucket": bucket,
                 "key": key,
             }
@@ -462,7 +506,7 @@ class CfnGitHubRepositoryProps:
         *,
         repository_name: builtins.str,
         repository_owner: builtins.str,
-        code: typing.Optional[typing.Union[CfnGitHubRepository.CodeProperty, _IResolvable_a771d0ef]] = None,
+        code: typing.Optional[typing.Union[typing.Union[CfnGitHubRepository.CodeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
         connection_arn: typing.Optional[builtins.str] = None,
         enable_issues: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
         is_private: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
@@ -510,7 +554,17 @@ class CfnGitHubRepositoryProps:
                 repository_description="repositoryDescription"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__e87d67c3c5cc77f8471f3efaaa8ccca8c715c75e7b8da3a6f4de11fc3de05c5d)
+            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
+            check_type(argname="argument repository_owner", value=repository_owner, expected_type=type_hints["repository_owner"])
+            check_type(argname="argument code", value=code, expected_type=type_hints["code"])
+            check_type(argname="argument connection_arn", value=connection_arn, expected_type=type_hints["connection_arn"])
+            check_type(argname="argument enable_issues", value=enable_issues, expected_type=type_hints["enable_issues"])
+            check_type(argname="argument is_private", value=is_private, expected_type=type_hints["is_private"])
+            check_type(argname="argument repository_access_token", value=repository_access_token, expected_type=type_hints["repository_access_token"])
+            check_type(argname="argument repository_description", value=repository_description, expected_type=type_hints["repository_description"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "repository_name": repository_name,
             "repository_owner": repository_owner,
         }
@@ -687,7 +741,18 @@ class GitHubRepositoryProps:
                 contents_key="import.zip"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__f2da2743ba4706217d329c539152fb16db4d9d4b2167a0eb5fba6ea9bee9d4e6)
+            check_type(argname="argument access_token", value=access_token, expected_type=type_hints["access_token"])
+            check_type(argname="argument contents_bucket", value=contents_bucket, expected_type=type_hints["contents_bucket"])
+            check_type(argname="argument contents_key", value=contents_key, expected_type=type_hints["contents_key"])
+            check_type(argname="argument owner", value=owner, expected_type=type_hints["owner"])
+            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
+            check_type(argname="argument contents_s3_version", value=contents_s3_version, expected_type=type_hints["contents_s3_version"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument enable_issues", value=enable_issues, expected_type=type_hints["enable_issues"])
+            check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "access_token": access_token,
             "contents_bucket": contents_bucket,
             "contents_key": contents_key,
@@ -828,7 +893,7 @@ class IGitHubRepository(_IResource_8c1dbbbd, typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="owner")
     def owner(self) -> builtins.str:
         '''(experimental) the repository owner.
@@ -837,7 +902,7 @@ class IGitHubRepository(_IResource_8c1dbbbd, typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repo")
     def repo(self) -> builtins.str:
         '''(experimental) the repository name.
@@ -848,7 +913,7 @@ class IGitHubRepository(_IResource_8c1dbbbd, typing_extensions.Protocol):
 
 
 class _IGitHubRepositoryProxy(
-    jsii.proxy_for(_IResource_8c1dbbbd) # type: ignore[misc]
+    jsii.proxy_for(_IResource_8c1dbbbd), # type: ignore[misc]
 ):
     '''(experimental) GitHubRepository resource interface.
 
@@ -857,7 +922,7 @@ class _IGitHubRepositoryProxy(
 
     __jsii_type__: typing.ClassVar[str] = "monocdk.aws_codestar.IGitHubRepository"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="owner")
     def owner(self) -> builtins.str:
         '''(experimental) the repository owner.
@@ -866,7 +931,7 @@ class _IGitHubRepositoryProxy(
         '''
         return typing.cast(builtins.str, jsii.get(self, "owner"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repo")
     def repo(self) -> builtins.str:
         '''(experimental) the repository name.
@@ -928,7 +993,7 @@ class GitHubRepository(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         access_token: _SecretValue_c18506ef,
@@ -956,6 +1021,10 @@ class GitHubRepository(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__4ec831a56afa88faddd96488fe6165c0e0a638d756d5118859307b5cef1b35e6)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitHubRepositoryProps(
             access_token=access_token,
             contents_bucket=contents_bucket,
@@ -970,7 +1039,7 @@ class GitHubRepository(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="owner")
     def owner(self) -> builtins.str:
         '''(experimental) the repository owner.
@@ -979,7 +1048,7 @@ class GitHubRepository(
         '''
         return typing.cast(builtins.str, jsii.get(self, "owner"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="repo")
     def repo(self) -> builtins.str:
         '''(experimental) the repository name.
@@ -999,3 +1068,141 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__8e6417a8cd803b26540e4b0aeb36c45a341ff26da7e791df675df50fb97584c4(
+    scope: _Construct_e78e779f,
+    id: builtins.str,
+    *,
+    repository_name: builtins.str,
+    repository_owner: builtins.str,
+    code: typing.Optional[typing.Union[typing.Union[CfnGitHubRepository.CodeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
+    connection_arn: typing.Optional[builtins.str] = None,
+    enable_issues: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
+    is_private: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
+    repository_access_token: typing.Optional[builtins.str] = None,
+    repository_description: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e316e6706e3d8c947158e9450f45c1c0ce5b1b7d89bbac929d3e37a79a874fc3(
+    inspector: _TreeInspector_1cd1894e,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cd458298fc1e20ba4a7ff1d912df53387d79a747e37d7a388fc8e490b1f7a8d0(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__78ad89e3d016b25b56cffa283f881b0d0f6a6ac7e932d07e77309aa8bfab79ad(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e100b8474946ec04f4b7eee7ef43bf55a420a9bef06925b5b6caf56a5e3ff1d0(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__06fdac87038483579345a9d6e16a8575f32eb023fd4accf654d2d02f77114e71(
+    value: typing.Optional[typing.Union[CfnGitHubRepository.CodeProperty, _IResolvable_a771d0ef]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c0ba8394d7ea0b0c6071ce2aafef37306e47a68e53ea2cef4deeba55a7342f99(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5402b5c800b0a50cb0141a0d17dd4219f94ff7e43b6c26a07a63b3c2e88bcdb7(
+    value: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bfd7dbdce873af1a204d661071d9d24c0d4bf72acfbe3dba81f1c9736ad4016c(
+    value: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__01d8678cd01273d281a5e55ee2af6acc9e50cc0f76c18cd129b895b27b681911(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2f2170856c0701f4ac4b7480e4d4e6c71d349c174fbbd977f616360503a7e403(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__151b349c77f1a4f8ded96e7a22c46e35ac66f8e14e1da6dedbbed79e929b9805(
+    *,
+    s3: typing.Union[typing.Union[CfnGitHubRepository.S3Property, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__51e1fbe1a2a485214d39aeb1220ee489138a0d32cffa831dc40b075b935090d9(
+    *,
+    bucket: builtins.str,
+    key: builtins.str,
+    object_version: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e87d67c3c5cc77f8471f3efaaa8ccca8c715c75e7b8da3a6f4de11fc3de05c5d(
+    *,
+    repository_name: builtins.str,
+    repository_owner: builtins.str,
+    code: typing.Optional[typing.Union[typing.Union[CfnGitHubRepository.CodeProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]] = None,
+    connection_arn: typing.Optional[builtins.str] = None,
+    enable_issues: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
+    is_private: typing.Optional[typing.Union[builtins.bool, _IResolvable_a771d0ef]] = None,
+    repository_access_token: typing.Optional[builtins.str] = None,
+    repository_description: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f2da2743ba4706217d329c539152fb16db4d9d4b2167a0eb5fba6ea9bee9d4e6(
+    *,
+    access_token: _SecretValue_c18506ef,
+    contents_bucket: _IBucket_73486e29,
+    contents_key: builtins.str,
+    owner: builtins.str,
+    repository_name: builtins.str,
+    contents_s3_version: typing.Optional[builtins.str] = None,
+    description: typing.Optional[builtins.str] = None,
+    enable_issues: typing.Optional[builtins.bool] = None,
+    visibility: typing.Optional[RepositoryVisibility] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4ec831a56afa88faddd96488fe6165c0e0a638d756d5118859307b5cef1b35e6(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    access_token: _SecretValue_c18506ef,
+    contents_bucket: _IBucket_73486e29,
+    contents_key: builtins.str,
+    owner: builtins.str,
+    repository_name: builtins.str,
+    contents_s3_version: typing.Optional[builtins.str] = None,
+    description: typing.Optional[builtins.str] = None,
+    enable_issues: typing.Optional[builtins.bool] = None,
+    visibility: typing.Optional[RepositoryVisibility] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
