@@ -76,9 +76,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     CfnResource as _CfnResource_e0a482dc,
     Construct as _Construct_e78e779f,
@@ -141,7 +143,7 @@ class CfnNotificationRule(
         event_type_ids: typing.Sequence[builtins.str],
         name: builtins.str,
         resource: builtins.str,
-        targets: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union["CfnNotificationRule.TargetProperty", _IResolvable_a771d0ef]]],
+        targets: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union["CfnNotificationRule.TargetProperty", typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
         created_by: typing.Optional[builtins.str] = None,
         event_type_id: typing.Optional[builtins.str] = None,
         status: typing.Optional[builtins.str] = None,
@@ -153,16 +155,20 @@ class CfnNotificationRule(
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
         :param detail_type: The level of detail to include in the notifications for this resource. ``BASIC`` will include only the contents of the event as it would appear in Amazon CloudWatch. ``FULL`` will include any supplemental information provided by AWS CodeStar Notifications and/or the service for the resource for which the notification is created.
-        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
         :param name: The name for the notification rule. Notification rule names must be unique in your AWS account .
         :param resource: The Amazon Resource Name (ARN) of the resource to associate with the notification rule. Supported resources include pipelines in AWS CodePipeline , repositories in AWS CodeCommit , and build projects in AWS CodeBuild .
-        :param targets: A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+        :param targets: A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
         :param created_by: ``AWS::CodeStarNotifications::NotificationRule.CreatedBy``.
         :param event_type_id: ``AWS::CodeStarNotifications::NotificationRule.EventTypeId``.
         :param status: The status of the notification rule. The default value is ``ENABLED`` . If the status is set to ``DISABLED`` , notifications aren't sent for the notification rule.
         :param tags: A list of tags to apply to this notification rule. Key names cannot start with " ``aws`` ".
         :param target_address: ``AWS::CodeStarNotifications::NotificationRule.TargetAddress``.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__3d5b4ee7fc8d58fecd981bcd61082b6e77ad5dc3c26d5c004b79905d623550e6)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnNotificationRuleProps(
             detail_type=detail_type,
             event_type_ids=event_type_ids,
@@ -184,6 +190,9 @@ class CfnNotificationRule(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__5ccc0030880e0925e7b8a2f47b0c14928915ec8f0f01d2535f9d1d14036593b2)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -194,15 +203,18 @@ class CfnNotificationRule(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__e0bb770fa4b4650c05714c6c82e8197480fdc3a451963c3a244bc9bac1d9e53f)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The CloudFormation resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
         '''
@@ -210,12 +222,12 @@ class CfnNotificationRule(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> _TagManager_0b7ab120:
         '''A list of tags to apply to this notification rule.
@@ -226,7 +238,7 @@ class CfnNotificationRule(
         '''
         return typing.cast(_TagManager_0b7ab120, jsii.get(self, "tags"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="detailType")
     def detail_type(self) -> builtins.str:
         '''The level of detail to include in the notifications for this resource.
@@ -239,14 +251,17 @@ class CfnNotificationRule(
 
     @detail_type.setter
     def detail_type(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__17d5e04005b45e977110f769b49d9d026c5575ae8de313eb25f3f12ea9cb6cba)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "detailType", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventTypeIds")
     def event_type_ids(self) -> typing.List[builtins.str]:
         '''A list of event types associated with this notification rule.
 
-        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-eventtypeids
         '''
@@ -254,9 +269,12 @@ class CfnNotificationRule(
 
     @event_type_ids.setter
     def event_type_ids(self, value: typing.List[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__e0ce0e0a09f50eae4e39bddde55433f48d0827256724d7b345e9330b9219363f)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventTypeIds", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''The name for the notification rule.
@@ -269,9 +287,12 @@ class CfnNotificationRule(
 
     @name.setter
     def name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__e4a2f2c6350e4c018e9b25d7c405268519525589cfe9e0f129f6b780146dd63c)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="resource")
     def resource(self) -> builtins.str:
         '''The Amazon Resource Name (ARN) of the resource to associate with the notification rule.
@@ -284,14 +305,17 @@ class CfnNotificationRule(
 
     @resource.setter
     def resource(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__3f21e03967024d5ee65027b14005a74b0843e307782c100e8d4679879695a0ce)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resource", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="targets")
     def targets(
         self,
     ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnNotificationRule.TargetProperty", _IResolvable_a771d0ef]]]:
-        '''A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+        '''A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-targets
         '''
@@ -302,9 +326,12 @@ class CfnNotificationRule(
         self,
         value: typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union["CfnNotificationRule.TargetProperty", _IResolvable_a771d0ef]]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__e19025bbdec7f4a1858b3ef8bbd38e2a36c6f5b3dcccf84992a59d55b4335709)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targets", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="createdBy")
     def created_by(self) -> typing.Optional[builtins.str]:
         '''``AWS::CodeStarNotifications::NotificationRule.CreatedBy``.
@@ -315,9 +342,12 @@ class CfnNotificationRule(
 
     @created_by.setter
     def created_by(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__85706609935313590a291adcfed1253ff3db15969d572f77ea2240c20d1d7d21)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "createdBy", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventTypeId")
     def event_type_id(self) -> typing.Optional[builtins.str]:
         '''``AWS::CodeStarNotifications::NotificationRule.EventTypeId``.
@@ -328,9 +358,12 @@ class CfnNotificationRule(
 
     @event_type_id.setter
     def event_type_id(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__5d725f316dd4a011ff157f043518ddf5e8e0a08458d3a7004511f036159eec0b)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventTypeId", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="status")
     def status(self) -> typing.Optional[builtins.str]:
         '''The status of the notification rule.
@@ -343,9 +376,12 @@ class CfnNotificationRule(
 
     @status.setter
     def status(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__70bd0c5a5abbed0dea07b610c7d06a0d647de2a52d93ea50396edf302f110783)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "status", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="targetAddress")
     def target_address(self) -> typing.Optional[builtins.str]:
         '''``AWS::CodeStarNotifications::NotificationRule.TargetAddress``.
@@ -356,6 +392,9 @@ class CfnNotificationRule(
 
     @target_address.setter
     def target_address(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__8674c415cfce5cce8a9ad9ceb6df0c7f744a55daca1085b1fd0902a5fe9cd2ea)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targetAddress", value)
 
     @jsii.data_type(
@@ -389,7 +428,11 @@ class CfnNotificationRule(
                     target_type="targetType"
                 )
             '''
-            self._values: typing.Dict[str, typing.Any] = {
+            if __debug__:
+                type_hints = typing.get_type_hints(_typecheckingstub__3efa77e19882605dee1fb84cf5435d5023e1a54873fe95aef1e85c886ed88f7a)
+                check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
+                check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "target_address": target_address,
                 "target_type": target_type,
             }
@@ -453,7 +496,7 @@ class CfnNotificationRuleProps:
         event_type_ids: typing.Sequence[builtins.str],
         name: builtins.str,
         resource: builtins.str,
-        targets: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[CfnNotificationRule.TargetProperty, _IResolvable_a771d0ef]]],
+        targets: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
         created_by: typing.Optional[builtins.str] = None,
         event_type_id: typing.Optional[builtins.str] = None,
         status: typing.Optional[builtins.str] = None,
@@ -463,10 +506,10 @@ class CfnNotificationRuleProps:
         '''Properties for defining a ``CfnNotificationRule``.
 
         :param detail_type: The level of detail to include in the notifications for this resource. ``BASIC`` will include only the contents of the event as it would appear in Amazon CloudWatch. ``FULL`` will include any supplemental information provided by AWS CodeStar Notifications and/or the service for the resource for which the notification is created.
-        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
         :param name: The name for the notification rule. Notification rule names must be unique in your AWS account .
         :param resource: The Amazon Resource Name (ARN) of the resource to associate with the notification rule. Supported resources include pipelines in AWS CodePipeline , repositories in AWS CodeCommit , and build projects in AWS CodeBuild .
-        :param targets: A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+        :param targets: A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
         :param created_by: ``AWS::CodeStarNotifications::NotificationRule.CreatedBy``.
         :param event_type_id: ``AWS::CodeStarNotifications::NotificationRule.EventTypeId``.
         :param status: The status of the notification rule. The default value is ``ENABLED`` . If the status is set to ``DISABLED`` , notifications aren't sent for the notification rule.
@@ -502,7 +545,19 @@ class CfnNotificationRuleProps:
                 target_address="targetAddress"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__e6d2390bec363dee21d65a1e194c758fb7a7288bc9e6efba113d1ac4421d75a2)
+            check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
+            check_type(argname="argument event_type_ids", value=event_type_ids, expected_type=type_hints["event_type_ids"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
+            check_type(argname="argument targets", value=targets, expected_type=type_hints["targets"])
+            check_type(argname="argument created_by", value=created_by, expected_type=type_hints["created_by"])
+            check_type(argname="argument event_type_id", value=event_type_id, expected_type=type_hints["event_type_id"])
+            check_type(argname="argument status", value=status, expected_type=type_hints["status"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
+            check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "detail_type": detail_type,
             "event_type_ids": event_type_ids,
             "name": name,
@@ -536,7 +591,7 @@ class CfnNotificationRuleProps:
     def event_type_ids(self) -> typing.List[builtins.str]:
         '''A list of event types associated with this notification rule.
 
-        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-eventtypeids
         '''
@@ -572,7 +627,7 @@ class CfnNotificationRuleProps:
     def targets(
         self,
     ) -> typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnNotificationRule.TargetProperty, _IResolvable_a771d0ef]]]:
-        '''A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+        '''A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-targets
         '''
@@ -667,7 +722,7 @@ class INotificationRule(_IResource_8c1dbbbd, typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="notificationRuleArn")
     def notification_rule_arn(self) -> builtins.str:
         '''(experimental) The ARN of the notification rule (i.e. arn:aws:codestar-notifications:::notificationrule/01234abcde).
@@ -691,7 +746,7 @@ class INotificationRule(_IResource_8c1dbbbd, typing_extensions.Protocol):
 
 
 class _INotificationRuleProxy(
-    jsii.proxy_for(_IResource_8c1dbbbd) # type: ignore[misc]
+    jsii.proxy_for(_IResource_8c1dbbbd), # type: ignore[misc]
 ):
     '''(experimental) Represents a notification rule.
 
@@ -700,7 +755,7 @@ class _INotificationRuleProxy(
 
     __jsii_type__: typing.ClassVar[str] = "monocdk.aws_codestarnotifications.INotificationRule"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="notificationRuleArn")
     def notification_rule_arn(self) -> builtins.str:
         '''(experimental) The ARN of the notification rule (i.e. arn:aws:codestar-notifications:::notificationrule/01234abcde).
@@ -720,6 +775,9 @@ class _INotificationRuleProxy(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__3fa31086b3c1202e3d20c7d0c595fb98c032e1dcfd1e140fb464d98f5381442b)
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         return typing.cast(builtins.bool, jsii.invoke(self, "addTarget", [target]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -736,7 +794,7 @@ class INotificationRuleSource(typing_extensions.Protocol):
     @jsii.member(jsii_name="bindAsNotificationRuleSource")
     def bind_as_notification_rule_source(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleSourceConfig":
         '''(experimental) Returns a source configuration for notification rule.
 
@@ -758,7 +816,7 @@ class _INotificationRuleSourceProxy:
     @jsii.member(jsii_name="bindAsNotificationRuleSource")
     def bind_as_notification_rule_source(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleSourceConfig":
         '''(experimental) Returns a source configuration for notification rule.
 
@@ -766,6 +824,9 @@ class _INotificationRuleSourceProxy:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__a3896285109db55f3971fd1651556d508b726c7e3aaffa70df546909c6ef403d)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast("NotificationRuleSourceConfig", jsii.invoke(self, "bindAsNotificationRuleSource", [scope]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -782,7 +843,7 @@ class INotificationRuleTarget(typing_extensions.Protocol):
     @jsii.member(jsii_name="bindAsNotificationRuleTarget")
     def bind_as_notification_rule_target(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleTargetConfig":
         '''(experimental) Returns a target configuration for notification rule.
 
@@ -804,7 +865,7 @@ class _INotificationRuleTargetProxy:
     @jsii.member(jsii_name="bindAsNotificationRuleTarget")
     def bind_as_notification_rule_target(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleTargetConfig":
         '''(experimental) Returns a target configuration for notification rule.
 
@@ -812,6 +873,9 @@ class _INotificationRuleTargetProxy:
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__fe1fbe4983ab64404556a0bda74fdc29ce550b0d11af05ff1ec8500e6c50fe2d)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast("NotificationRuleTargetConfig", jsii.invoke(self, "bindAsNotificationRuleTarget", [scope]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -827,8 +891,8 @@ class NotificationRule(
     '''(experimental) A new notification rule.
 
     :stability: experimental
-    :exampleMetadata: infused
     :resource: AWS::CodeStarNotifications::NotificationRule
+    :exampleMetadata: infused
 
     Example::
 
@@ -859,7 +923,7 @@ class NotificationRule(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         events: typing.Sequence[builtins.str],
@@ -881,6 +945,10 @@ class NotificationRule(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__32874533f084f8a5fffc55c25247e4430b8070ab4d59bc77cdc86e837b79ecfb)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = NotificationRuleProps(
             events=events,
             source=source,
@@ -892,11 +960,11 @@ class NotificationRule(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromNotificationRuleArn") # type: ignore[misc]
+    @jsii.member(jsii_name="fromNotificationRuleArn")
     @builtins.classmethod
     def from_notification_rule_arn(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         notification_rule_arn: builtins.str,
     ) -> INotificationRule:
@@ -908,6 +976,11 @@ class NotificationRule(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__ec8649b208676ea4071f3eac0a605230da9007b636bfe826bae1fabefd20f1dc)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument notification_rule_arn", value=notification_rule_arn, expected_type=type_hints["notification_rule_arn"])
         return typing.cast(INotificationRule, jsii.sinvoke(cls, "fromNotificationRuleArn", [scope, id, notification_rule_arn]))
 
     @jsii.member(jsii_name="addTarget")
@@ -918,9 +991,12 @@ class NotificationRule(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__11a96e2c67119e584995da3a1eca0728c2165edf3252455f95f178b0d803ac11)
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         return typing.cast(builtins.bool, jsii.invoke(self, "addTarget", [target]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="notificationRuleArn")
     def notification_rule_arn(self) -> builtins.str:
         '''(experimental) The ARN of the notification rule (i.e. arn:aws:codestar-notifications:::notificationrule/01234abcde).
@@ -969,7 +1045,12 @@ class NotificationRuleOptions:
                 notification_rule_name="notificationRuleName"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__2ede2e6ab258b31e4b179da43217c60619f263a92b95b0eaae8dc0bd988a3fd1)
+            check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
+            check_type(argname="argument enabled", value=enabled, expected_type=type_hints["enabled"])
+            check_type(argname="argument notification_rule_name", value=notification_rule_name, expected_type=type_hints["notification_rule_name"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if detail_type is not None:
             self._values["detail_type"] = detail_type
         if enabled is not None:
@@ -1090,7 +1171,15 @@ class NotificationRuleProps(NotificationRuleOptions):
             )
             rule.add_target(slack)
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__84d2ac7ad815e4ca05a56760dd407d141a8cbd2e019f5f1fbfd72d34f5277159)
+            check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
+            check_type(argname="argument enabled", value=enabled, expected_type=type_hints["enabled"])
+            check_type(argname="argument notification_rule_name", value=notification_rule_name, expected_type=type_hints["notification_rule_name"])
+            check_type(argname="argument events", value=events, expected_type=type_hints["events"])
+            check_type(argname="argument source", value=source, expected_type=type_hints["source"])
+            check_type(argname="argument targets", value=targets, expected_type=type_hints["targets"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "events": events,
             "source": source,
         }
@@ -1216,7 +1305,10 @@ class NotificationRuleSourceConfig:
                 source_arn="sourceArn"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__6ed63fdd11405d319123afc63a15c364e0ca31ec427a0b7c2f4dd88a35da75bb)
+            check_type(argname="argument source_arn", value=source_arn, expected_type=type_hints["source_arn"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "source_arn": source_arn,
         }
 
@@ -1273,7 +1365,11 @@ class NotificationRuleTargetConfig:
                 target_type="targetType"
             )
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__866f83e1e34480822ecaebe8cc38b37b59759aafc484924107df05f2d8594071)
+            check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
+            check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "target_address": target_address,
             "target_type": target_type,
         }
@@ -1327,3 +1423,193 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__3d5b4ee7fc8d58fecd981bcd61082b6e77ad5dc3c26d5c004b79905d623550e6(
+    scope: _Construct_e78e779f,
+    id: builtins.str,
+    *,
+    detail_type: builtins.str,
+    event_type_ids: typing.Sequence[builtins.str],
+    name: builtins.str,
+    resource: builtins.str,
+    targets: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
+    created_by: typing.Optional[builtins.str] = None,
+    event_type_id: typing.Optional[builtins.str] = None,
+    status: typing.Optional[builtins.str] = None,
+    tags: typing.Any = None,
+    target_address: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5ccc0030880e0925e7b8a2f47b0c14928915ec8f0f01d2535f9d1d14036593b2(
+    inspector: _TreeInspector_1cd1894e,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e0bb770fa4b4650c05714c6c82e8197480fdc3a451963c3a244bc9bac1d9e53f(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__17d5e04005b45e977110f769b49d9d026c5575ae8de313eb25f3f12ea9cb6cba(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e0ce0e0a09f50eae4e39bddde55433f48d0827256724d7b345e9330b9219363f(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e4a2f2c6350e4c018e9b25d7c405268519525589cfe9e0f129f6b780146dd63c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3f21e03967024d5ee65027b14005a74b0843e307782c100e8d4679879695a0ce(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e19025bbdec7f4a1858b3ef8bbd38e2a36c6f5b3dcccf84992a59d55b4335709(
+    value: typing.Union[_IResolvable_a771d0ef, typing.List[typing.Union[CfnNotificationRule.TargetProperty, _IResolvable_a771d0ef]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__85706609935313590a291adcfed1253ff3db15969d572f77ea2240c20d1d7d21(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5d725f316dd4a011ff157f043518ddf5e8e0a08458d3a7004511f036159eec0b(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__70bd0c5a5abbed0dea07b610c7d06a0d647de2a52d93ea50396edf302f110783(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8674c415cfce5cce8a9ad9ceb6df0c7f744a55daca1085b1fd0902a5fe9cd2ea(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3efa77e19882605dee1fb84cf5435d5023e1a54873fe95aef1e85c886ed88f7a(
+    *,
+    target_address: builtins.str,
+    target_type: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e6d2390bec363dee21d65a1e194c758fb7a7288bc9e6efba113d1ac4421d75a2(
+    *,
+    detail_type: builtins.str,
+    event_type_ids: typing.Sequence[builtins.str],
+    name: builtins.str,
+    resource: builtins.str,
+    targets: typing.Union[_IResolvable_a771d0ef, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[builtins.str, typing.Any]], _IResolvable_a771d0ef]]],
+    created_by: typing.Optional[builtins.str] = None,
+    event_type_id: typing.Optional[builtins.str] = None,
+    status: typing.Optional[builtins.str] = None,
+    tags: typing.Any = None,
+    target_address: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3fa31086b3c1202e3d20c7d0c595fb98c032e1dcfd1e140fb464d98f5381442b(
+    target: INotificationRuleTarget,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a3896285109db55f3971fd1651556d508b726c7e3aaffa70df546909c6ef403d(
+    scope: _constructs_77d1e7e8.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fe1fbe4983ab64404556a0bda74fdc29ce550b0d11af05ff1ec8500e6c50fe2d(
+    scope: _constructs_77d1e7e8.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__32874533f084f8a5fffc55c25247e4430b8070ab4d59bc77cdc86e837b79ecfb(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    events: typing.Sequence[builtins.str],
+    source: INotificationRuleSource,
+    targets: typing.Optional[typing.Sequence[INotificationRuleTarget]] = None,
+    detail_type: typing.Optional[DetailType] = None,
+    enabled: typing.Optional[builtins.bool] = None,
+    notification_rule_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ec8649b208676ea4071f3eac0a605230da9007b636bfe826bae1fabefd20f1dc(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    notification_rule_arn: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__11a96e2c67119e584995da3a1eca0728c2165edf3252455f95f178b0d803ac11(
+    target: INotificationRuleTarget,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2ede2e6ab258b31e4b179da43217c60619f263a92b95b0eaae8dc0bd988a3fd1(
+    *,
+    detail_type: typing.Optional[DetailType] = None,
+    enabled: typing.Optional[builtins.bool] = None,
+    notification_rule_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__84d2ac7ad815e4ca05a56760dd407d141a8cbd2e019f5f1fbfd72d34f5277159(
+    *,
+    detail_type: typing.Optional[DetailType] = None,
+    enabled: typing.Optional[builtins.bool] = None,
+    notification_rule_name: typing.Optional[builtins.str] = None,
+    events: typing.Sequence[builtins.str],
+    source: INotificationRuleSource,
+    targets: typing.Optional[typing.Sequence[INotificationRuleTarget]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6ed63fdd11405d319123afc63a15c364e0ca31ec427a0b7c2f4dd88a35da75bb(
+    *,
+    source_arn: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__866f83e1e34480822ecaebe8cc38b37b59759aafc484924107df05f2d8594071(
+    *,
+    target_address: builtins.str,
+    target_type: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
