@@ -90,6 +90,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
 from .. import Duration as _Duration_070aa057
@@ -331,7 +333,18 @@ class AuthenticateCognitoActionProps:
             CognitoStack(app, "integ-cognito")
             app.synth()
         '''
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__126c2b193c74c7cac68fc4e20f5a82cc78290273bc2a80551e14c98d114c987a)
+            check_type(argname="argument next", value=next, expected_type=type_hints["next"])
+            check_type(argname="argument user_pool", value=user_pool, expected_type=type_hints["user_pool"])
+            check_type(argname="argument user_pool_client", value=user_pool_client, expected_type=type_hints["user_pool_client"])
+            check_type(argname="argument user_pool_domain", value=user_pool_domain, expected_type=type_hints["user_pool_domain"])
+            check_type(argname="argument authentication_request_extra_params", value=authentication_request_extra_params, expected_type=type_hints["authentication_request_extra_params"])
+            check_type(argname="argument on_unauthenticated_request", value=on_unauthenticated_request, expected_type=type_hints["on_unauthenticated_request"])
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument session_cookie_name", value=session_cookie_name, expected_type=type_hints["session_cookie_name"])
+            check_type(argname="argument session_timeout", value=session_timeout, expected_type=type_hints["session_timeout"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "next": next,
             "user_pool": user_pool,
             "user_pool_client": user_pool_client,
@@ -470,3 +483,18 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__126c2b193c74c7cac68fc4e20f5a82cc78290273bc2a80551e14c98d114c987a(
+    *,
+    next: _ListenerAction_5de1dcc2,
+    user_pool: _IUserPool_5e500460,
+    user_pool_client: _IUserPoolClient_4cdf19bd,
+    user_pool_domain: _IUserPoolDomain_1ae2cfab,
+    authentication_request_extra_params: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    on_unauthenticated_request: typing.Optional[_UnauthenticatedAction_dce2040c] = None,
+    scope: typing.Optional[builtins.str] = None,
+    session_cookie_name: typing.Optional[builtins.str] = None,
+    session_timeout: typing.Optional[_Duration_070aa057] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
