@@ -10,7 +10,7 @@ will first upload all the assets to S3, and only then deploy the stacks. The S3
 locations of the uploaded assets will be passed in as CloudFormation Parameters
 to the relevant stacks.
 
-The following JavaScript example defines an directory asset which is archived as
+The following JavaScript example defines a directory asset which is archived as
 a .zip file and uploaded to S3 during deployment.
 
 ```python
@@ -55,7 +55,7 @@ cdk.CfnOutput(self, "S3ObjectURL", value=asset.s3_object_url)
 IAM roles, users or groups which need to be able to read assets in runtime will should be
 granted IAM permissions. To do that use the `asset.grantRead(principal)` method:
 
-The following examples grants an IAM group read permissions on an asset:
+The following example grants an IAM group read permissions on an asset:
 
 ```python
 group = iam.Group(self, "MyUserGroup")
@@ -195,9 +195,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     AssetHashType as _AssetHashType_49193809,
     AssetOptions as _AssetOptions_263e97ca,
@@ -244,7 +246,7 @@ class Asset(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         path: builtins.str,
@@ -256,7 +258,7 @@ class Asset(
         follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_49193809] = None,
-        bundling: typing.Optional[_BundlingOptions_ab115a99] = None,
+        bundling: typing.Optional[typing.Union[_BundlingOptions_ab115a99, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -274,6 +276,10 @@ class Asset(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__13ea0b207b616643e5f48bdbc8a6ec3ccfd25a60ac5df8b0793a54a5754cab69)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AssetProps(
             path=path,
             readers=readers,
@@ -310,6 +316,10 @@ class Asset(
         :see: https://github.com/aws/aws-cdk/issues/1432
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__4b7f3327145fc0d52a76837fa0e6cc7793e1063afe0454c46e317b9d52184864)
+            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
+            check_type(argname="argument resource_property", value=resource_property, expected_type=type_hints["resource_property"])
         return typing.cast(None, jsii.invoke(self, "addResourceMetadata", [resource, resource_property]))
 
     @jsii.member(jsii_name="grantRead")
@@ -320,9 +330,12 @@ class Asset(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__23e39b1a05408cccdd01cd4775316da443686431a2436321cf4b70a57d66a64a)
+            check_type(argname="argument grantee", value=grantee, expected_type=type_hints["grantee"])
         return typing.cast(None, jsii.invoke(self, "grantRead", [grantee]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="assetHash")
     def asset_hash(self) -> builtins.str:
         '''(experimental) A hash of this asset, which is available at construction time.
@@ -335,7 +348,7 @@ class Asset(
         '''
         return typing.cast(builtins.str, jsii.get(self, "assetHash"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="assetPath")
     def asset_path(self) -> builtins.str:
         '''(experimental) The path to the asset, relative to the current Cloud Assembly.
@@ -347,7 +360,7 @@ class Asset(
         '''
         return typing.cast(builtins.str, jsii.get(self, "assetPath"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="bucket")
     def bucket(self) -> _IBucket_73486e29:
         '''(experimental) The S3 bucket in which this asset resides.
@@ -356,7 +369,7 @@ class Asset(
         '''
         return typing.cast(_IBucket_73486e29, jsii.get(self, "bucket"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="httpUrl")
     def http_url(self) -> builtins.str:
         '''(experimental) Attribute which represents the S3 HTTP URL of this asset.
@@ -367,7 +380,7 @@ class Asset(
         '''
         return typing.cast(builtins.str, jsii.get(self, "httpUrl"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="isFile")
     def is_file(self) -> builtins.bool:
         '''(experimental) Indicates if this asset is a single file.
@@ -379,7 +392,7 @@ class Asset(
         '''
         return typing.cast(builtins.bool, jsii.get(self, "isFile"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="isZipArchive")
     def is_zip_archive(self) -> builtins.bool:
         '''(experimental) Indicates if this asset is a zip archive.
@@ -391,7 +404,7 @@ class Asset(
         '''
         return typing.cast(builtins.bool, jsii.get(self, "isZipArchive"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3BucketName")
     def s3_bucket_name(self) -> builtins.str:
         '''(experimental) Attribute that represents the name of the bucket this asset exists in.
@@ -400,7 +413,7 @@ class Asset(
         '''
         return typing.cast(builtins.str, jsii.get(self, "s3BucketName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3ObjectKey")
     def s3_object_key(self) -> builtins.str:
         '''(experimental) Attribute which represents the S3 object key of this asset.
@@ -409,7 +422,7 @@ class Asset(
         '''
         return typing.cast(builtins.str, jsii.get(self, "s3ObjectKey"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3ObjectUrl")
     def s3_object_url(self) -> builtins.str:
         '''(experimental) Attribute which represents the S3 URL of this asset.
@@ -420,7 +433,7 @@ class Asset(
         '''
         return typing.cast(builtins.str, jsii.get(self, "s3ObjectUrl"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3Url")
     def s3_url(self) -> builtins.str:
         '''(deprecated) Attribute which represents the S3 URL of this asset.
@@ -431,7 +444,7 @@ class Asset(
         '''
         return typing.cast(builtins.str, jsii.get(self, "s3Url"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="sourceHash")
     def source_hash(self) -> builtins.str:
         '''(deprecated) A cryptographic hash of the asset.
@@ -474,7 +487,7 @@ class AssetOptions(
         follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_49193809] = None,
-        bundling: typing.Optional[_BundlingOptions_ab115a99] = None,
+        bundling: typing.Optional[typing.Union[_BundlingOptions_ab115a99, typing.Dict[builtins.str, typing.Any]]] = None,
         readers: typing.Optional[typing.Sequence[_IGrantable_4c5a91d1]] = None,
         source_hash: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -508,7 +521,18 @@ class AssetOptions(
         '''
         if isinstance(bundling, dict):
             bundling = _BundlingOptions_ab115a99(**bundling)
-        self._values: typing.Dict[str, typing.Any] = {}
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__c7b4c2b7cb5d32ce7ba2dd428904e018839a16d7595bfd1e27fcc8931df77df0)
+            check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
+            check_type(argname="argument follow", value=follow, expected_type=type_hints["follow"])
+            check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
+            check_type(argname="argument follow_symlinks", value=follow_symlinks, expected_type=type_hints["follow_symlinks"])
+            check_type(argname="argument asset_hash", value=asset_hash, expected_type=type_hints["asset_hash"])
+            check_type(argname="argument asset_hash_type", value=asset_hash_type, expected_type=type_hints["asset_hash_type"])
+            check_type(argname="argument bundling", value=bundling, expected_type=type_hints["bundling"])
+            check_type(argname="argument readers", value=readers, expected_type=type_hints["readers"])
+            check_type(argname="argument source_hash", value=source_hash, expected_type=type_hints["source_hash"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if exclude is not None:
             self._values["exclude"] = exclude
         if follow is not None:
@@ -709,7 +733,7 @@ class AssetProps(AssetOptions):
         follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_49193809] = None,
-        bundling: typing.Optional[_BundlingOptions_ab115a99] = None,
+        bundling: typing.Optional[typing.Union[_BundlingOptions_ab115a99, typing.Dict[builtins.str, typing.Any]]] = None,
         readers: typing.Optional[typing.Sequence[_IGrantable_4c5a91d1]] = None,
         source_hash: typing.Optional[builtins.str] = None,
         path: builtins.str,
@@ -744,7 +768,19 @@ class AssetProps(AssetOptions):
         '''
         if isinstance(bundling, dict):
             bundling = _BundlingOptions_ab115a99(**bundling)
-        self._values: typing.Dict[str, typing.Any] = {
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__d41a4a86a1d6e95347d9f226638915cede7cc9149b4101b8aa151f876efb788b)
+            check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
+            check_type(argname="argument follow", value=follow, expected_type=type_hints["follow"])
+            check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
+            check_type(argname="argument follow_symlinks", value=follow_symlinks, expected_type=type_hints["follow_symlinks"])
+            check_type(argname="argument asset_hash", value=asset_hash, expected_type=type_hints["asset_hash"])
+            check_type(argname="argument asset_hash_type", value=asset_hash_type, expected_type=type_hints["asset_hash_type"])
+            check_type(argname="argument bundling", value=bundling, expected_type=type_hints["bundling"])
+            check_type(argname="argument readers", value=readers, expected_type=type_hints["readers"])
+            check_type(argname="argument source_hash", value=source_hash, expected_type=type_hints["source_hash"])
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "path": path,
         }
         if exclude is not None:
@@ -943,3 +979,65 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__13ea0b207b616643e5f48bdbc8a6ec3ccfd25a60ac5df8b0793a54a5754cab69(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    path: builtins.str,
+    readers: typing.Optional[typing.Sequence[_IGrantable_4c5a91d1]] = None,
+    source_hash: typing.Optional[builtins.str] = None,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow: typing.Optional[_FollowMode_98b05cc5] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_31d8bf46] = None,
+    follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
+    asset_hash: typing.Optional[builtins.str] = None,
+    asset_hash_type: typing.Optional[_AssetHashType_49193809] = None,
+    bundling: typing.Optional[typing.Union[_BundlingOptions_ab115a99, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4b7f3327145fc0d52a76837fa0e6cc7793e1063afe0454c46e317b9d52184864(
+    resource: _CfnResource_e0a482dc,
+    resource_property: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__23e39b1a05408cccdd01cd4775316da443686431a2436321cf4b70a57d66a64a(
+    grantee: _IGrantable_4c5a91d1,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c7b4c2b7cb5d32ce7ba2dd428904e018839a16d7595bfd1e27fcc8931df77df0(
+    *,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow: typing.Optional[_FollowMode_98b05cc5] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_31d8bf46] = None,
+    follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
+    asset_hash: typing.Optional[builtins.str] = None,
+    asset_hash_type: typing.Optional[_AssetHashType_49193809] = None,
+    bundling: typing.Optional[typing.Union[_BundlingOptions_ab115a99, typing.Dict[builtins.str, typing.Any]]] = None,
+    readers: typing.Optional[typing.Sequence[_IGrantable_4c5a91d1]] = None,
+    source_hash: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d41a4a86a1d6e95347d9f226638915cede7cc9149b4101b8aa151f876efb788b(
+    *,
+    exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
+    follow: typing.Optional[_FollowMode_98b05cc5] = None,
+    ignore_mode: typing.Optional[_IgnoreMode_31d8bf46] = None,
+    follow_symlinks: typing.Optional[_SymlinkFollowMode_abf4527a] = None,
+    asset_hash: typing.Optional[builtins.str] = None,
+    asset_hash_type: typing.Optional[_AssetHashType_49193809] = None,
+    bundling: typing.Optional[typing.Union[_BundlingOptions_ab115a99, typing.Dict[builtins.str, typing.Any]]] = None,
+    readers: typing.Optional[typing.Sequence[_IGrantable_4c5a91d1]] = None,
+    source_hash: typing.Optional[builtins.str] = None,
+    path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
