@@ -83,6 +83,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
 
@@ -92,7 +94,7 @@ class Default(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.Default"):
     :stability: experimental
     '''
 
-    @jsii.member(jsii_name="servicePrincipal") # type: ignore[misc]
+    @jsii.member(jsii_name="servicePrincipal")
     @builtins.classmethod
     def service_principal(
         cls,
@@ -113,9 +115,14 @@ class Default(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.Default"):
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__05004e17b1f785d1c8d508f9a12ba628b4093b33e9aa7386b6705e000a5c960a)
+            check_type(argname="argument service_fqn", value=service_fqn, expected_type=type_hints["service_fqn"])
+            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
+            check_type(argname="argument url_suffix", value=url_suffix, expected_type=type_hints["url_suffix"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "servicePrincipal", [service_fqn, region, url_suffix]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="VPC_ENDPOINT_SERVICE_NAME_PREFIX")
     def VPC_ENDPOINT_SERVICE_NAME_PREFIX(cls) -> builtins.str:
         '''(experimental) The default value for a VPC Endpoint Service name prefix, useful if you do not have a synthesize-time region literal available (all you have is ``{ "Ref": "AWS::Region" }``).
@@ -138,7 +145,7 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.Fact"):
         region_info.Fact.register(MyFact())
     '''
 
-    @jsii.member(jsii_name="find") # type: ignore[misc]
+    @jsii.member(jsii_name="find")
     @builtins.classmethod
     def find(
         cls,
@@ -154,9 +161,13 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.Fact"):
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__b6e34cbd95c7512205f09fca79e9476f2fd79534aa34ea0cfc5710efeae1eaae)
+            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         return typing.cast(typing.Optional[builtins.str], jsii.sinvoke(cls, "find", [region, name]))
 
-    @jsii.member(jsii_name="register") # type: ignore[misc]
+    @jsii.member(jsii_name="register")
     @builtins.classmethod
     def register(
         cls,
@@ -170,9 +181,13 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.Fact"):
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__a0da052ed5ca34eb55fe7bd2185ce19880cfc4a4cbaa5a6014efb4cc1a478bc0)
+            check_type(argname="argument fact", value=fact, expected_type=type_hints["fact"])
+            check_type(argname="argument allow_replacing", value=allow_replacing, expected_type=type_hints["allow_replacing"])
         return typing.cast(None, jsii.sinvoke(cls, "register", [fact, allow_replacing]))
 
-    @jsii.member(jsii_name="requireFact") # type: ignore[misc]
+    @jsii.member(jsii_name="requireFact")
     @builtins.classmethod
     def require_fact(cls, region: builtins.str, name: builtins.str) -> builtins.str:
         '''(experimental) Retrieve a fact from the Fact database.
@@ -185,9 +200,13 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.Fact"):
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__640e2c57af5b108929ac940bb29a85c04680b38a433967f2a97c1370f1909f94)
+            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "requireFact", [region, name]))
 
-    @jsii.member(jsii_name="unregister") # type: ignore[misc]
+    @jsii.member(jsii_name="unregister")
     @builtins.classmethod
     def unregister(
         cls,
@@ -203,9 +222,14 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.Fact"):
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__9890e917375bd8eb21cb383eafca9d8762b33f0882f23be0b25ae46a279d8a7b)
+            check_type(argname="argument region", value=region, expected_type=type_hints["region"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.sinvoke(cls, "unregister", [region, name, value]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="regions")
     def regions(cls) -> typing.List[builtins.str]:
         '''
@@ -238,7 +262,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
         '''
         jsii.create(self.__class__, self, [])
 
-    @jsii.member(jsii_name="cloudwatchLambdaInsightsVersion") # type: ignore[misc]
+    @jsii.member(jsii_name="cloudwatchLambdaInsightsVersion")
     @builtins.classmethod
     def cloudwatch_lambda_insights_version(
         cls,
@@ -252,9 +276,13 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__643cad4ea1dcc132ad3a401d97a37817e71a0fe4e5d45b5ead2b613750ac0a49)
+            check_type(argname="argument version", value=version, expected_type=type_hints["version"])
+            check_type(argname="argument arch", value=arch, expected_type=type_hints["arch"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "cloudwatchLambdaInsightsVersion", [version, arch]))
 
-    @jsii.member(jsii_name="servicePrincipal") # type: ignore[misc]
+    @jsii.member(jsii_name="servicePrincipal")
     @builtins.classmethod
     def service_principal(cls, service: builtins.str) -> builtins.str:
         '''(experimental) The name of the regional service principal for a given service.
@@ -263,9 +291,12 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__96533f5313ef8448cd6754e61b361a4ab6d70821b72089c8a24dd5bc62b0b57f)
+            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "servicePrincipal", [service]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="APPMESH_ECR_ACCOUNT")
     def APPMESH_ECR_ACCOUNT(cls) -> builtins.str:
         '''(experimental) The ID of the AWS account that owns the public ECR repository that contains the AWS App Mesh Envoy Proxy images in a given region.
@@ -274,7 +305,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
         '''
         return typing.cast(builtins.str, jsii.sget(cls, "APPMESH_ECR_ACCOUNT"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="CDK_METADATA_RESOURCE_AVAILABLE")
     def CDK_METADATA_RESOURCE_AVAILABLE(cls) -> builtins.str:
         '''(experimental) Whether the AWS::CDK::Metadata CloudFormation Resource is available in-region or not.
@@ -286,7 +317,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
         '''
         return typing.cast(builtins.str, jsii.sget(cls, "CDK_METADATA_RESOURCE_AVAILABLE"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="DLC_REPOSITORY_ACCOUNT")
     def DLC_REPOSITORY_ACCOUNT(cls) -> builtins.str:
         '''(experimental) The ID of the AWS account that owns the public ECR repository that contains the AWS Deep Learning Containers images in a given region.
@@ -295,7 +326,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
         '''
         return typing.cast(builtins.str, jsii.sget(cls, "DLC_REPOSITORY_ACCOUNT"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="DOMAIN_SUFFIX")
     def DOMAIN_SUFFIX(cls) -> builtins.str:
         '''(experimental) The domain suffix for a region (e.g: 'amazonaws.com`).
@@ -304,7 +335,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
         '''
         return typing.cast(builtins.str, jsii.sget(cls, "DOMAIN_SUFFIX"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="EBS_ENV_ENDPOINT_HOSTED_ZONE_ID")
     def EBS_ENV_ENDPOINT_HOSTED_ZONE_ID(cls) -> builtins.str:
         '''(experimental) The hosted zone ID used by Route 53 to alias a EBS environment endpoint in this region (e.g: Z2O1EMRO9K5GLX).
@@ -313,7 +344,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
         '''
         return typing.cast(builtins.str, jsii.sget(cls, "EBS_ENV_ENDPOINT_HOSTED_ZONE_ID"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ELBV2_ACCOUNT")
     def ELBV2_ACCOUNT(cls) -> builtins.str:
         '''(experimental) The account for ELBv2 in this region.
@@ -322,7 +353,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
         '''
         return typing.cast(builtins.str, jsii.sget(cls, "ELBV2_ACCOUNT"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="FIREHOSE_CIDR_BLOCK")
     def FIREHOSE_CIDR_BLOCK(cls) -> builtins.str:
         '''(experimental) The CIDR block used by Kinesis Data Firehose servers.
@@ -331,7 +362,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
         '''
         return typing.cast(builtins.str, jsii.sget(cls, "FIREHOSE_CIDR_BLOCK"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="PARTITION")
     def PARTITION(cls) -> builtins.str:
         '''(experimental) The name of the partition for a region (e.g: 'aws', 'aws-cn', ...).
@@ -340,7 +371,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
         '''
         return typing.cast(builtins.str, jsii.sget(cls, "PARTITION"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="S3_STATIC_WEBSITE_ENDPOINT")
     def S3_STATIC_WEBSITE_ENDPOINT(cls) -> builtins.str:
         '''(experimental) The endpoint used for hosting S3 static websites.
@@ -349,7 +380,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
         '''
         return typing.cast(builtins.str, jsii.sget(cls, "S3_STATIC_WEBSITE_ENDPOINT"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="S3_STATIC_WEBSITE_ZONE_53_HOSTED_ZONE_ID")
     def S3_STATIC_WEBSITE_ZONE_53_HOSTED_ZONE_ID(cls) -> builtins.str:
         '''(experimental) The endpoint used for aliasing S3 static websites in Route 53.
@@ -358,7 +389,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.FactName"
         '''
         return typing.cast(builtins.str, jsii.sget(cls, "S3_STATIC_WEBSITE_ZONE_53_HOSTED_ZONE_ID"))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="VPC_ENDPOINT_SERVICE_NAME_PREFIX")
     def VPC_ENDPOINT_SERVICE_NAME_PREFIX(cls) -> builtins.str:
         '''(experimental) The prefix for VPC Endpoint Service names, cn.com.amazonaws.vpce for China regions, com.amazonaws.vpce otherwise.
@@ -375,7 +406,7 @@ class IFact(typing_extensions.Protocol):
     :stability: experimental
     '''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''(experimental) The name of this fact.
@@ -386,7 +417,7 @@ class IFact(typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="region")
     def region(self) -> builtins.str:
         '''(experimental) The region for which this fact applies.
@@ -395,7 +426,7 @@ class IFact(typing_extensions.Protocol):
         '''
         ...
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="value")
     def value(self) -> typing.Optional[builtins.str]:
         '''(experimental) The value of this fact.
@@ -413,7 +444,7 @@ class _IFactProxy:
 
     __jsii_type__: typing.ClassVar[str] = "monocdk.region_info.IFact"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''(experimental) The name of this fact.
@@ -424,7 +455,7 @@ class _IFactProxy:
         '''
         return typing.cast(builtins.str, jsii.get(self, "name"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="region")
     def region(self) -> builtins.str:
         '''(experimental) The region for which this fact applies.
@@ -433,7 +464,7 @@ class _IFactProxy:
         '''
         return typing.cast(builtins.str, jsii.get(self, "region"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="value")
     def value(self) -> typing.Optional[builtins.str]:
         '''(experimental) The value of this fact.
@@ -462,7 +493,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         region.service_principal("logs.amazonaws.com")
     '''
 
-    @jsii.member(jsii_name="get") # type: ignore[misc]
+    @jsii.member(jsii_name="get")
     @builtins.classmethod
     def get(cls, name: builtins.str) -> "RegionInfo":
         '''(experimental) Obtain region info for a given region name.
@@ -471,9 +502,12 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__4fc91282de8b4f6701b5eef059d4bb1fb319b25ae9e7a4936fca1c50bb93bf66)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         return typing.cast("RegionInfo", jsii.sinvoke(cls, "get", [name]))
 
-    @jsii.member(jsii_name="limitedRegionMap") # type: ignore[misc]
+    @jsii.member(jsii_name="limitedRegionMap")
     @builtins.classmethod
     def limited_region_map(
         cls,
@@ -492,9 +526,13 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__2f88879d9fdd720a531669194191d4fb28d0f0823833f5423e3efbf7560d32dd)
+            check_type(argname="argument fact_name", value=fact_name, expected_type=type_hints["fact_name"])
+            check_type(argname="argument partitions", value=partitions, expected_type=type_hints["partitions"])
         return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.sinvoke(cls, "limitedRegionMap", [fact_name, partitions]))
 
-    @jsii.member(jsii_name="regionMap") # type: ignore[misc]
+    @jsii.member(jsii_name="regionMap")
     @builtins.classmethod
     def region_map(
         cls,
@@ -511,6 +549,9 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__7d6b4da698a4751bbc1138405d9be2690def3c71b704e9cbaafee874bb42c6fb)
+            check_type(argname="argument fact_name", value=fact_name, expected_type=type_hints["fact_name"])
         return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.sinvoke(cls, "regionMap", [fact_name]))
 
     @jsii.member(jsii_name="cloudwatchLambdaInsightsArn")
@@ -526,6 +567,10 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__b6193c6b65f1eb6a8c1db08bb7605b8fdd73c99c41f36c859c14706ea7e75e1a)
+            check_type(argname="argument insights_version", value=insights_version, expected_type=type_hints["insights_version"])
+            check_type(argname="argument architecture", value=architecture, expected_type=type_hints["architecture"])
         return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "cloudwatchLambdaInsightsArn", [insights_version, architecture]))
 
     @jsii.member(jsii_name="servicePrincipal")
@@ -536,9 +581,12 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__47a6577091227f63eefd4dbcd7c49bfa9cc09b45f339d3d0e69ebaf4c52d57ca)
+            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
         return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "servicePrincipal", [service]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="regions")
     def regions(cls) -> typing.List["RegionInfo"]:
         '''
@@ -551,7 +599,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(typing.List["RegionInfo"], jsii.sget(cls, "regions"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="cdkMetadataResourceAvailable")
     def cdk_metadata_resource_available(self) -> builtins.bool:
         '''(experimental) Whether the ``AWS::CDK::Metadata`` CloudFormation Resource is available in this region or not.
@@ -560,7 +608,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(builtins.bool, jsii.get(self, "cdkMetadataResourceAvailable"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''
@@ -568,7 +616,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(builtins.str, jsii.get(self, "name"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="appMeshRepositoryAccount")
     def app_mesh_repository_account(self) -> typing.Optional[builtins.str]:
         '''(experimental) The ID of the AWS account that owns the public ECR repository that contains the AWS App Mesh Envoy Proxy images in a given region.
@@ -577,7 +625,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "appMeshRepositoryAccount"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dlcRepositoryAccount")
     def dlc_repository_account(self) -> typing.Optional[builtins.str]:
         '''(experimental) The ID of the AWS account that owns the public ECR repository containing the AWS Deep Learning Containers images in this region.
@@ -586,7 +634,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "dlcRepositoryAccount"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="domainSuffix")
     def domain_suffix(self) -> typing.Optional[builtins.str]:
         '''(experimental) The domain name suffix (e.g: amazonaws.com) for this region.
@@ -595,7 +643,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "domainSuffix"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ebsEnvEndpointHostedZoneId")
     def ebs_env_endpoint_hosted_zone_id(self) -> typing.Optional[builtins.str]:
         '''(experimental) The hosted zone ID used by Route 53 to alias a EBS environment endpoint in this region (e.g: Z2O1EMRO9K5GLX).
@@ -604,7 +652,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "ebsEnvEndpointHostedZoneId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="elbv2Account")
     def elbv2_account(self) -> typing.Optional[builtins.str]:
         '''(experimental) The account ID for ELBv2 in this region.
@@ -613,7 +661,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "elbv2Account"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="firehoseCidrBlock")
     def firehose_cidr_block(self) -> typing.Optional[builtins.str]:
         '''(experimental) The CIDR block used by Kinesis Data Firehose servers.
@@ -622,7 +670,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "firehoseCidrBlock"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="partition")
     def partition(self) -> typing.Optional[builtins.str]:
         '''(experimental) The name of the ARN partition for this region (e.g: aws).
@@ -631,7 +679,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "partition"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3StaticWebsiteEndpoint")
     def s3_static_website_endpoint(self) -> typing.Optional[builtins.str]:
         '''(experimental) The endpoint used by S3 static website hosting in this region (e.g: s3-static-website-us-east-1.amazonaws.com).
@@ -640,7 +688,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "s3StaticWebsiteEndpoint"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3StaticWebsiteHostedZoneId")
     def s3_static_website_hosted_zone_id(self) -> typing.Optional[builtins.str]:
         '''(experimental) The hosted zone ID used by Route 53 to alias a S3 static website in this region (e.g: Z2O1EMRO9K5GLX).
@@ -649,7 +697,7 @@ class RegionInfo(metaclass=jsii.JSIIMeta, jsii_type="monocdk.region_info.RegionI
         '''
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "s3StaticWebsiteHostedZoneId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vpcEndpointServiceNamePrefix")
     def vpc_endpoint_service_name_prefix(self) -> typing.Optional[builtins.str]:
         '''(experimental) The prefix for VPC Endpoint Service names, cn.com.amazonaws.vpce for China regions, com.amazonaws.vpce otherwise.
@@ -668,3 +716,85 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__05004e17b1f785d1c8d508f9a12ba628b4093b33e9aa7386b6705e000a5c960a(
+    service_fqn: builtins.str,
+    region: builtins.str,
+    url_suffix: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b6e34cbd95c7512205f09fca79e9476f2fd79534aa34ea0cfc5710efeae1eaae(
+    region: builtins.str,
+    name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a0da052ed5ca34eb55fe7bd2185ce19880cfc4a4cbaa5a6014efb4cc1a478bc0(
+    fact: IFact,
+    allow_replacing: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__640e2c57af5b108929ac940bb29a85c04680b38a433967f2a97c1370f1909f94(
+    region: builtins.str,
+    name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9890e917375bd8eb21cb383eafca9d8762b33f0882f23be0b25ae46a279d8a7b(
+    region: builtins.str,
+    name: builtins.str,
+    value: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__643cad4ea1dcc132ad3a401d97a37817e71a0fe4e5d45b5ead2b613750ac0a49(
+    version: builtins.str,
+    arch: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__96533f5313ef8448cd6754e61b361a4ab6d70821b72089c8a24dd5bc62b0b57f(
+    service: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4fc91282de8b4f6701b5eef059d4bb1fb319b25ae9e7a4936fca1c50bb93bf66(
+    name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2f88879d9fdd720a531669194191d4fb28d0f0823833f5423e3efbf7560d32dd(
+    fact_name: builtins.str,
+    partitions: typing.Sequence[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7d6b4da698a4751bbc1138405d9be2690def3c71b704e9cbaafee874bb42c6fb(
+    fact_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b6193c6b65f1eb6a8c1db08bb7605b8fdd73c99c41f36c859c14706ea7e75e1a(
+    insights_version: builtins.str,
+    architecture: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__47a6577091227f63eefd4dbcd7c49bfa9cc09b45f339d3d0e69ebaf4c52d57ca(
+    service: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
